'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const graphql = require('graphql');
const firestore = require('@google-cloud/firestore');

const Timestamp = new graphql.GraphQLScalarType({
    name: 'Timestamp',
    description: '',
    serialize(value) {
        let v = value;
        if (!(v instanceof firestore.Timestamp) &&
            typeof v !== 'object' &&
            typeof v.toDate === 'function' &&
            typeof v !== 'string' &&
            typeof v !== 'number') {
            throw new TypeError(`Value is not an instance of Date, Date string or number: ${JSON.stringify(v)}`);
        }
        if (typeof v === 'string') {
            const date = new Date();
            date.setTime(Date.parse(value));
            try {
                v = firestore.Timestamp.fromDate(date);
            }
            catch (e) {
                throw new TypeError(`Value is not a valid Date: ${JSON.stringify(v)}`);
            }
        }
        else if (typeof v === 'number') {
            v = firestore.Timestamp.fromMillis(v);
        }
        if (Number.isNaN(v.seconds)) {
            throw new TypeError(`Value is not a valid Date: ${JSON.stringify(v)}`);
        }
        return v.toDate();
    },
    parseValue(value) {
        const date = new Date(value);
        if (Number.isNaN(date.getTime())) {
            throw new graphql.GraphQLError(`Value is not a valid Date: ${JSON.stringify(value)}`);
        }
        return firestore.Timestamp.fromDate(date);
    },
    parseLiteral(ast) {
        if (ast.kind === graphql.Kind.INT) {
            return firestore.Timestamp.fromDate(new Date(parseInt(ast.value, 10)));
        }
        else if (ast.kind === graphql.Kind.STRING) {
            if (this.parseValue) {
                return this.parseValue(ast.value);
            }
        }
        return null;
    },
});

const index = /*#__PURE__*/Object.freeze({
  __proto__: null,
  Timestamp: Timestamp
});

const Timestamp$1 = 'scalar Timestamp';
const typeDefs = [Timestamp$1];

exports.TimestampResolver = Timestamp;
exports.TimestampTypeDefinition = Timestamp$1;
exports.resolvers = index;
exports.typeDefs = typeDefs;
//# sourceMappingURL=index.cjs.js.map
