import { GraphQLScalarType, GraphQLError, Kind } from 'graphql';
import { Timestamp as Timestamp$2 } from '@google-cloud/firestore';

const Timestamp = new GraphQLScalarType({
    name: 'Timestamp',
    description: '',
    serialize(value) {
        let v = value;
        if (!(v instanceof Timestamp$2) &&
            typeof v !== 'object' &&
            typeof v.toDate === 'function' &&
            typeof v !== 'string' &&
            typeof v !== 'number') {
            throw new TypeError(`Value is not an instance of Date, Date string or number: ${JSON.stringify(v)}`);
        }
        if (typeof v === 'string') {
            const date = new Date();
            date.setTime(Date.parse(value));
            try {
                v = Timestamp$2.fromDate(date);
            }
            catch (e) {
                throw new TypeError(`Value is not a valid Date: ${JSON.stringify(v)}`);
            }
        }
        else if (typeof v === 'number') {
            v = Timestamp$2.fromMillis(v);
        }
        if (Number.isNaN(v.seconds)) {
            throw new TypeError(`Value is not a valid Date: ${JSON.stringify(v)}`);
        }
        return v.toDate();
    },
    parseValue(value) {
        const date = new Date(value);
        if (Number.isNaN(date.getTime())) {
            throw new GraphQLError(`Value is not a valid Date: ${JSON.stringify(value)}`);
        }
        return Timestamp$2.fromDate(date);
    },
    parseLiteral(ast) {
        if (ast.kind === Kind.INT) {
            return Timestamp$2.fromDate(new Date(parseInt(ast.value, 10)));
        }
        else if (ast.kind === Kind.STRING) {
            if (this.parseValue) {
                return this.parseValue(ast.value);
            }
        }
        return null;
    },
});

const index = /*#__PURE__*/Object.freeze({
  __proto__: null,
  Timestamp: Timestamp
});

const Timestamp$1 = 'scalar Timestamp';
const typeDefs = [Timestamp$1];

export { Timestamp as TimestampResolver, Timestamp$1 as TimestampTypeDefinition, index as resolvers, typeDefs };
//# sourceMappingURL=index.esm.js.map
